@@ -19,7 +19,7 @@
 #ifndef _BackupProfileInfoWidget_h_
 #define _BackupProfileInfoWidget_h_
 
-#include <qwidget.h>
+#include <QWidget>
 
 class BackupProfileWidget;
 
