@@ -24,26 +24,20 @@
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
 
-
-
 #ifndef SEARCH_H
 #define SEARCH_H
 
-#include "../config.h"
-
 // Standard Headers
 #include <stdio.h>
 
-
 class QLineEdit;
 class QCheckBox;
 
 // KDE headers
-#include <kapplication.h>
 #include <kmenubar.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
 
-class Search : public KDialogBase
+class Search : public KDialog
 {
   Q_OBJECT
 
